# -*- coding: utf-8 -*-
# !/usr/bin/python
# Create Date 2018/7/5 0005
__author__ = 'huohuo'
import PythonMagick
from PyPDF2 import PdfFileReader
from pdf2img import pdf2img

C_RESOURCE_FILE=u'/tumor'
C_PDFNAME=u'facets_cval_50.pdf'
C_JPGNAME=u'/tumor/%s.jpg'

input_stream = file(C_RESOURCE_FILE+'\\'+C_PDFNAME, 'rb')
pdf_input = PdfFileReader(input_stream,strict=False)    #错误1
page_count = pdf_input.getNumPages()

img = PythonMagick.Image()    # empty object first
img.density('300')           # set the density for reading (DPI); must be as a string
print page_count
for i in range(page_count):
    try:
        img.read(C_RESOURCE_FILE+'\\'+C_PDFNAME + ('[%s]'%i))     #分页读取 PDF
        imgCustRes = PythonMagick.Image(img)  # make a copy
        imgCustRes.sample('x1600')
        imgCustRes.write(C_RESOURCE_FILE+'\\'+(C_JPGNAME%i))
    except Exception, e:
        print e
        pass

print 'done'
if __name__ == "__main__":
    pass
    




# -*- coding: utf-8 -*-
# !/usr/bin/python
# Create Date 2018/6/28 0028
__author__ = 'huohuo'
import datetime
import os
import fitz
import glob
import PythonMagick
from PythonMagick import Image
bgcolor = '#FFFFFF'


def pdf2img(input_pdf, postfix='.png', **kwargs):
    # print os.path.exists(input_pdf)
    img = Image(input_pdf)
    img.density('300')
    size = "%sx%s" % (img.columns(), img.rows())
    output_img = Image(size, bgcolor)
    output_img.type = img.type
    output_img.composite(img, 0, 0, PythonMagick.CompositeOperator.SrcOverCompositeOp)
    output_img.resize(str(img.rows()))
    output_img.magick('JPG')
    output_img.quality(75)
    if 'out_path' in kwargs:
        output_jpg = kwargs['out_path']
    else:
        output_jpg = input_pdf + postfix
    if os.path.exists(output_jpg):
        os.remove(output_jpg)
    output_img.write(output_jpg)


if __name__ == "__main__":
    pdffilename = '/tumor/facets_cval_50.pdf'
    img_path = '/tumor/image'
    # pdf2img(pdf_path)
    import PyPDF2
    pdf_im = PyPDF2.PdfFileReader(file(pdffilename, "rb"))
    npage = pdf_im.getNumPages()
    print(npage)
    for p in range(npage):
        p1 = '%s[%s]' % (pdffilename, p)
        print p1
        p_path = os.path.join(img_path), 'tumor_balanced_vafs%s.png' % p
        im = PythonMagick.Image(p1)
        im.density('3000')
        im.write(p_path)
        # try:
        #
        # # try:
        # #     pdf2img('%s[%s]' % (pdffilename, p))
        # except:
        #
        #     continue

    # for p in range(npage):
    #     im = PythonMagick.Image()
    #     im.density('300')
    #     im.read(pdffilename + '[' + str(p) +']')
    #     im.write('file_out-' + str(p)+ '.png')
    #     #im.read(pdffilename + '[' + str(p) +']')


# pyMuPDF_fitz(pdf_path, img_path)
    pass

    

